==> codebuild-1.60.0-sources.jar: software/amazon/awscdk/services/codebuild/StateChangeEvent.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * Event fields for the CodeBuild "state change" event.
 * <p>
 * @see https://docs.aws.amazon.com/codebuild/latest/userguide/sample-build-notifications.html#sample-build-notifications-ref
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:32.930Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.StateChangeEvent")
public class StateChangeEvent extends software.amazon.jsii.JsiiObject {

    protected StateChangeEvent(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected StateChangeEvent(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Return the build id.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.String getBuildId() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codebuild.StateChangeEvent.class, "buildId", java.lang.String.class);
    }

    /**
     * The triggering build's status.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.String getBuildStatus() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codebuild.StateChangeEvent.class, "buildStatus", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.String getCurrentPhase() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codebuild.StateChangeEvent.class, "currentPhase", java.lang.String.class);
    }

    /**
     * The triggering build's project name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.String getProjectName() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codebuild.StateChangeEvent.class, "projectName", java.lang.String.class);
    }
}

==> codebuild-1.93.0-sources.jar: software/amazon/awscdk/services/codebuild/StateChangeEvent.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * Event fields for the CodeBuild "state change" event.
 * <p>
 * @see https://docs.aws.amazon.com/codebuild/latest/userguide/sample-build-notifications.html#sample-build-notifications-ref
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:51.405Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.StateChangeEvent")
public class StateChangeEvent extends software.amazon.jsii.JsiiObject {

    protected StateChangeEvent(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected StateChangeEvent(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Return the build id.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.String getBuildId() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codebuild.StateChangeEvent.class, "buildId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * The triggering build's status.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.String getBuildStatus() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codebuild.StateChangeEvent.class, "buildStatus", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.String getCurrentPhase() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codebuild.StateChangeEvent.class, "currentPhase", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * The triggering build's project name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull java.lang.String getProjectName() {
        return software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codebuild.StateChangeEvent.class, "projectName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
